summaryrefslogtreecommitdiff
path: root/vendor/thecodingmachine/safe/generated/json.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/thecodingmachine/safe/generated/json.php')
-rw-r--r--vendor/thecodingmachine/safe/generated/json.php35
1 files changed, 10 insertions, 25 deletions
diff --git a/vendor/thecodingmachine/safe/generated/json.php b/vendor/thecodingmachine/safe/generated/json.php
index dad455ccd..e524c6178 100644
--- a/vendor/thecodingmachine/safe/generated/json.php
+++ b/vendor/thecodingmachine/safe/generated/json.php
@@ -6,9 +6,14 @@ use Safe\Exceptions\JsonException;
/**
* Returns a string containing the JSON representation of the supplied
- * value.
+ * value. If the parameter is an array or object,
+ * it will be serialized recursively.
*
- * The encoding is affected by the supplied options
+ * If a value to be serialized is an object, then by default only publicly visible
+ * properties will be included. Alternatively, a class may implement JsonSerializable
+ * to control how its values are serialized to JSON.
+ *
+ * The encoding is affected by the supplied flags
* and additionally the encoding of float values depends on the value of
* serialize_precision.
*
@@ -19,7 +24,7 @@ use Safe\Exceptions\JsonException;
*
* PHP implements a superset of JSON as specified in the original
* RFC 7159.
* @param int $options Bitmask consisting of
* JSON_FORCE_OBJECT,
* JSON_HEX_QUOT,
* JSON_HEX_TAG,
@@ -42,30 +47,10 @@ use Safe\Exceptions\JsonException;
* @throws JsonException
*
*/
-function json_encode($value, int $options = 0, int $depth = 512): string
-{
- error_clear_last();
- $result = \json_encode($value, $options, $depth);
- if ($result === false) {
- throw JsonException::createFromPhpError();
- }
- return $result;
-}
-
-
-/**
- * Returns the error string of the last json_encode or json_decode
- * call, which did not specify JSON_THROW_ON_ERROR.
- *
- * @return string Returns the error message on success, "No error" if no
- * error has occurred.
- * @throws JsonException
- *
- */
-function json_last_error_msg(): string
+function json_encode($value, int $flags = 0, int $depth = 512): string
{
error_clear_last();
- $result = \json_last_error_msg();
+ $result = \json_encode($value, $flags, $depth);
if ($result === false) {
throw JsonException::createFromPhpError();
}
@@ -19,7 +24,7 @@ use Safe\Exceptions\JsonException;
* PHP implements a superset of JSON as specified in the original
* RFC 7159.
- * @param int $options Bitmask consisting of
+ * @param int $flags Bitmask consisting of
* JSON_FORCE_OBJECT,
* JSON_HEX_QUOT,